Wand_
~~~~~

Wand is a ``ctypes``-based simple `MagickWand API`_ binding for Python.
It doesn't cover all functionalities of MagickWand API currently.

.. _Wand: http://styleshare.github.com/wand/
.. _MagickWand API: http://www.imagemagick.org/script/magick-wand.php

